@@ -24,8 +24,9 @@ def main(sys_args: Optional[List[str]] = None) -> None:
     parser.add_argument(
         "application", help="The application to dispatch to as path.to.module:instance.path"
     )
+    parser.add_argument("--access-log", help="Deprecated, see access-logfile", default=sentinel)
     parser.add_argument(
-        "--access-log",
+        "--access-logfile",
         help="The target location for the access log, use `-` for stdout",
         default=sentinel,
     )
@@ -63,8 +64,11 @@ def main(sys_args: Optional[List[str]] = None) -> None:
         action="store_true",
         default=sentinel,
     )
+    parser.add_argument("--error-log", help="Deprecated, see error-logfile", default=sentinel)
     parser.add_argument(
-        "--error-log",
+        "--error-logfile",
+        "--log-file",
+        dest="error_logfile",
         help="The target location for the error log, use `-` for stderr",
         default=sentinel,
     )
@@ -93,6 +97,9 @@ def main(sys_args: Optional[List[str]] = None) -> None:
         default=[],
         action="append",
     )
+    parser.add_argument(
+        "--log-level", help="The (error) log level, defaults to info", default="info"
+    )
     parser.add_argument(
         "-p", "--pid", help="Location to write the PID (Program ID) to.", default=sentinel
     )
@@ -106,12 +113,9 @@ def main(sys_args: Optional[List[str]] = None) -> None:
         "--root-path", help="The setting for the ASGI root_path variable", default=sentinel
     )
     parser.add_argument(
-        "--uvloop",
-        dest="uvloop",
-        help="Enable uvloop usage (Deprecated, use `--worker-class uvloop` instead)",
-        action="store_true",
-        default=sentinel,
+        "--statsd-host", help="The host:port of the statsd server", default=sentinel
     )
+    parser.add_argument("--statsd-prefix", help="Prefix for all statsd messages", default="")
 
     def _convert_verify_mode(value: str) -> ssl.VerifyMode:  # type: ignore
         try:
@@ -136,11 +140,18 @@ def main(sys_args: Optional[List[str]] = None) -> None:
     args = parser.parse_args(sys_args or sys.argv[1:])
     config = _load_config(args.config)
     config.application_path = args.application
+    config.loglevel = args.log_level
 
     if args.access_logformat is not sentinel:
         config.access_log_format = args.access_logformat
     if args.access_log is not sentinel:
-        config.access_log_target = args.access_log
+        warnings.warn(
+            "The --access-log argument is deprecated, use `--access-logfile` instead",
+            DeprecationWarning,
+        )
+        config.accesslog = args.access_log
+    if args.access_logfile is not sentinel:
+        config.accesslog = args.access_logfile
     if args.backlog is not sentinel:
         config.backlog = args.backlog
     if args.ca_certs is not sentinel:
@@ -154,7 +165,13 @@ def main(sys_args: Optional[List[str]] = None) -> None:
     if args.debug is not sentinel:
         config.debug = args.debug
     if args.error_log is not sentinel:
-        config.error_log_target = args.error_log
+        warnings.warn(
+            "The --error-log argument is deprecated, use `--error-logfile` instead",
+            DeprecationWarning,
+        )
+        config.errorlog = args.error_log
+    if args.error_logfile is not sentinel:
+        config.errorlog = args.error_log
     if args.keep_alive is not sentinel:
         config.keep_alive_timeout = args.keep_alive
     if args.keyfile is not sentinel:
@@ -165,12 +182,10 @@ def main(sys_args: Optional[List[str]] = None) -> None:
         config.root_path = args.root_path
     if args.reload is not sentinel:
         config.use_reloader = args.reload
-    if args.uvloop is not sentinel:
-        warnings.warn(
-            "The uvloop argument is deprecated, use `--worker-class uvloop` instead",
-            DeprecationWarning,
-        )
-        config.worker_class = "uvloop"
+    if args.statsd_host is not sentinel:
+        config.statsd_host = args.statsd_host
+    if args.statsd_prefix is not sentinel:
+        config.statsd_prefix = args.statsd_prefix
     if args.worker_class is not sentinel:
         config.worker_class = args.worker_class
     if args.workers is not sentinel:
@@ -181,12 +196,6 @@ def main(sys_args: Optional[List[str]] = None) -> None:
     if len(args.insecure_binds) > 0:
         config.insecure_bind = args.insecure_binds
 
-    for bind in config.bind:
-        scheme = "https" if config.ssl_enabled else "http"
-        print(f"Running on {bind} over {scheme} (CTRL + C to quit)")  # noqa: T001
-    for bind in config.insecure_bind:
-        print(f"Running on {bind} over http (CTRL + C to quit)")  # noqa: T001
-
     run(config)
 
 
