@@ -5,12 +5,9 @@ import ssl
 from multiprocessing.synchronize import Event as EventType
 from typing import Any, Coroutine, Optional
 
-from .base import HTTPServer
-from .h2 import H2Server
-from .h11 import H11Server
 from .lifespan import Lifespan
-from .wsproto import WebsocketServer
-from ..asgi.run import H2CProtocolRequired, H2ProtocolAssumed, WebsocketProtocolRequired
+from .server import Server
+from .statsd import StatsdLogger
 from ..config import Config, Sockets
 from ..typing import ASGIFramework
 from ..utils import (
@@ -18,6 +15,7 @@ from ..utils import (
     load_application,
     MustReloadException,
     observe_changes,
+    repr_socket_addr,
     restart,
     Shutdown,
 )
@@ -32,68 +30,6 @@ def _raise_shutdown(*args: Any) -> None:
     raise Shutdown()
 
 
-class Server(asyncio.Protocol):
-    def __init__(self, app: ASGIFramework, loop: asyncio.AbstractEventLoop, config: Config) -> None:
-        self.app = app
-        self.loop = loop
-        self.config = config
-        self._server: Optional[HTTPServer] = None
-        self._ssl_enabled = False
-
-    def connection_made(self, transport: asyncio.BaseTransport) -> None:
-        ssl_object = transport.get_extra_info("ssl_object")
-        if ssl_object is not None:
-            self._ssl_enabled = True
-            protocol = ssl_object.selected_alpn_protocol()
-        else:
-            protocol = "http/1.1"
-
-        if protocol == "h2":
-            self._server = H2Server(self.app, self.loop, self.config, transport)
-        else:
-            self._server = H11Server(self.app, self.loop, self.config, transport)
-
-    def connection_lost(self, exception: Exception) -> None:
-        self._server.connection_lost(exception)
-
-    def data_received(self, data: bytes) -> None:
-        try:
-            self._server.data_received(data)
-        except WebsocketProtocolRequired as error:
-            self._server = WebsocketServer(
-                self.app,
-                self.loop,
-                self.config,
-                self._server.transport,
-                upgrade_request=error.request,
-            )
-        except H2CProtocolRequired as error:
-            self._server = H2Server(
-                self.app,
-                self.loop,
-                self.config,
-                self._server.transport,
-                upgrade_request=error.request,
-            )
-        except H2ProtocolAssumed as error:
-            self._server = H2Server(
-                self.app, self.loop, self.config, self._server.transport, received_data=error.data
-            )
-
-    def eof_received(self) -> bool:
-        if self._ssl_enabled:
-            # Returning anything other than False has no affect under
-            # SSL, and just raises an annoying warning.
-            return False
-        return self._server.eof_received()
-
-    def pause_writing(self) -> None:
-        self._server.pause_writing()
-
-    def resume_writing(self) -> None:
-        self._server.resume_writing()
-
-
 async def _windows_signal_support() -> None:
     # See https://bugs.python.org/issue23057, to catch signals on
     # Windows it is necessary for an IO event to happen periodically.
@@ -108,10 +44,16 @@ async def worker_serve(
     sockets: Optional[Sockets] = None,
     shutdown_event: Optional[EventType] = None,
 ) -> None:
+    config.set_statsd_logger_class(StatsdLogger)
+
     lifespan = Lifespan(app, config)
     lifespan_task = asyncio.ensure_future(lifespan.handle_lifespan())
 
     await lifespan.wait_for_startup()
+    if lifespan_task.done():
+        exception = lifespan_task.exception()
+        if exception is not None:
+            raise exception
 
     if sockets is None:
         sockets = config.create_sockets()
@@ -149,24 +91,32 @@ async def worker_serve(
         ssl_context = config.create_ssl_context()
         ssl_handshake_timeout = config.ssl_handshake_timeout
 
-    servers = [
-        await loop.create_server(  # type: ignore
-            lambda: Server(app, loop, config),
-            backlog=config.backlog,
-            ssl=ssl_context,
-            sock=sock,
-            ssl_handshake_timeout=ssl_handshake_timeout,
-        )
-        for sock in sockets.secure_sockets
-    ]
-    servers.extend(
-        [
-            await loop.create_server(  # type: ignore
-                lambda: Server(app, loop, config), backlog=config.backlog, sock=sock
+    async def _server_callback(reader: asyncio.StreamReader, writer: asyncio.StreamWriter) -> None:
+        await Server(app, loop, config, reader, writer)
+
+    servers = []
+    for sock in sockets.secure_sockets:
+        servers.append(
+            await asyncio.start_server(
+                _server_callback,
+                backlog=config.backlog,
+                loop=loop,
+                ssl=ssl_context,
+                sock=sock,
+                ssl_handshake_timeout=ssl_handshake_timeout,
             )
-            for sock in sockets.insecure_sockets
-        ]
-    )
+        )
+        bind = repr_socket_addr(sock.family, sock.getsockname())
+        await config.log.info(f"Running on {bind} over https (CTRL + C to quit)")
+
+    for sock in sockets.insecure_sockets:
+        servers.append(
+            await asyncio.start_server(
+                _server_callback, backlog=config.backlog, loop=loop, sock=sock
+            )
+        )
+        bind = repr_socket_addr(sock.family, sock.getsockname())
+        await config.log.info(f"Running on {bind} over http (CTRL + C to quit)")
 
     reload_ = False
     try:
