@@ -204,7 +204,8 @@ class WSStream:
             # Allow app to finish after close
             return
 
-        if message is None:  # App has errored
+        if message is None:  # ASGI App has finished sending messages
+            # Cleanup if required
             if self.state == ASGIWebsocketState.HANDSHAKE:
                 await self._send_error_response(500)
                 await self.config.log.access(
