@@ -42,6 +42,7 @@ async def _handle(
             raise
     except Exception:
         await config.log.exception("Error in ASGI Framework")
+    finally:
         await send(None)
 
 
@@ -85,10 +86,10 @@ class Server:
             socket = self.stream.socket
             ssl = False
 
-        client = parse_socket_addr(socket.family, socket.getpeername())
-        server = parse_socket_addr(socket.family, socket.getsockname())
-
         try:
+            client = parse_socket_addr(socket.family, socket.getpeername())
+            server = parse_socket_addr(socket.family, socket.getsockname())
+
             async with trio.open_nursery() as nursery:
                 self.nursery = nursery
                 self.protocol = ProtocolWrapper(
@@ -113,7 +114,9 @@ class Server:
         if isinstance(event, RawData):
             async with self.send_lock:
                 try:
-                    await self.stream.send_all(event.data)
+                    with trio.CancelScope() as cancel_scope:
+                        cancel_scope.shield = True
+                        await self.stream.send_all(event.data)
                 except trio.BrokenResourceError:
                     await self.protocol.handle(Closed())
         elif isinstance(event, Closed):
