@@ -3,13 +3,12 @@ import os
 import platform
 import socket
 import sys
+from enum import Enum
 from importlib import import_module
 from multiprocessing.synchronize import Event as EventType
 from pathlib import Path
-from time import time
 from types import ModuleType
 from typing import Any, Awaitable, Callable, cast, Dict, List, Optional, Tuple
-from wsgiref.handlers import format_date_time
 
 from .typing import ASGI2Framework, ASGI3Framework, ASGIFramework
 
@@ -36,18 +35,25 @@ class LifespanTimeout(Exception):
 
 class LifespanFailure(Exception):
     def __init__(self, stage: str, message: str) -> None:
-        super().__init__(f"Lifespan failure in {stage}. {message}")
+        super().__init__(f"Lifespan failure in {stage}. '{message}'")
+
+
+class UnexpectedMessage(Exception):
+    def __init__(self, state: Enum, message_type: str) -> None:
+        super().__init__(f"Unexpected message type, {message_type} given the state {state}")
+
+
+class FrameTooLarge(Exception):
+    pass
 
 
 def suppress_body(method: str, status_code: int) -> bool:
     return method == "HEAD" or 100 <= status_code < 200 or status_code in {204, 304, 412}
 
 
-def response_headers(protocol: str) -> List[Tuple[bytes, bytes]]:
-    return [
-        (b"date", format_date_time(time()).encode("ascii")),
-        (b"server", f"hypercorn-{protocol}".encode("ascii")),
-    ]
+def build_and_validate_headers(headers: List[Tuple[bytes, bytes]]) -> List[Tuple[bytes, bytes]]:
+    # Validates that the header name and value are bytes
+    return [(bytes(name).lower().strip(), bytes(value).strip()) for name, value in headers]
 
 
 def load_application(path: str) -> ASGIFramework:
@@ -67,7 +73,7 @@ def load_application(path: str) -> ASGIFramework:
     try:
         module = import_module(import_name)
     except ModuleNotFoundError as error:
-        if error.name == import_name:  # type: ignore
+        if error.name == import_name:
             raise NoAppException()
         else:
             raise
@@ -154,6 +160,17 @@ def parse_socket_addr(family: int, address: tuple) -> Optional[Tuple[str, int]]:
         return None
 
 
+def repr_socket_addr(family: int, address: tuple) -> str:
+    if family == socket.AF_INET:
+        return f"{address[0]}:{address[1]}"
+    elif family == socket.AF_INET6:
+        return f"[{address[0]}]:{address[1]}"
+    elif family == socket.AF_UNIX:
+        return f"unix:{address}"
+    else:
+        return f"{address}"
+
+
 async def invoke_asgi(app: ASGIFramework, scope: dict, receive: Callable, send: Callable) -> None:
     if _is_asgi_2(app):
         scope["asgi"]["version"] = "2.0"
